# Findings

> 조사 결과 저장소. 2-Action Rule에 따라 기록.
> view/browser 작업 2개 후 반드시 여기에 기록!

---

## [YYYY-MM-DD] [주제]

### 질문
[무엇을 찾고 있었나]

### 발견
[찾은 내용 요약]

### 소스
[링크, 파일 경로]

### 결론
[다음 액션]

---

<!--
예시:

## [2026-01-16] JWT 인증 구현 방법

### 질문
Next.js에서 JWT 인증을 어떻게 구현하나?

### 발견
- next-auth 사용이 표준
- JWT 토큰은 httpOnly 쿠키에 저장
- refresh token rotation 권장

### 소스
- https://next-auth.js.org/configuration/options
- src/lib/auth.ts (기존 코드)

### 결론
next-auth v5 사용, 기존 auth.ts 코드 확장

---
-->
